pvclock vsyscall support + KVM hypervisor support
Get series with b4
b4 am [email protected]Versions newest first
- v1 Latest15 patches 0 repliesNew
Patches in v1 No applies recorded yet
| # | Subject and files | Size | Replies | Applied |
|---|---|---|---|---|
| 1/15 | KVM: x86: retain pvclock guest stopped bit in guest memoryarch/ | +13 | 0 replies | |
| 2/15 | x86: pvclock: make sure rdtsc doesnt speculate out of regionarch/ | +2 | 0 replies | |
| 3/15 | x86: pvclock: remove pvclock_shadow_timearch/ | +9 | 0 replies | |
| 4/15 | x86: pvclock: create helper for pvclock data retrievalarch/ arch/ | +27 | 0 replies | |
| 5/15 | x86: pvclock: fix flags usage racearch/ arch/ | +7 | 0 replies | |
| 6/15 | x86: pvclock: introduce helper to read flagsarch/ arch/ | +14 | 0 replies | |
| 7/15 | sched: add notifier for cross-cpu migrationsinclude/ kernel/ | +23 | 0 replies | |
| 8/15 | x86: pvclock: generic pvclock vsyscall initializationarch/ arch/ arch/ +2 more | +106 | 0 replies | |
| 9/15 | x86: kvm guest: pvclock vsyscall supportarch/ arch/ arch/ | +69 | 0 replies | |
| 10/15 | x86: vsyscall: pass mode to gettime backendarch/ | +3 | 0 replies | |
| 11/15 | x86: vdso: pvclock gettime supportarch/ arch/ arch/ | +83 | 0 replies | |
| 12/15 | KVM: x86: introduce facility to support vsyscall pvclock, via MSRDocumentation/ arch/ arch/ +3 more | +106 | 0 replies | |
| 13/15 | KVM: x86: pass host_tsc to read_l1_tscarch/ arch/ arch/ +2 more | +9 | 0 replies | |
| 14/15 | time: export time information for KVM pvclockinclude/ kernel/ | +56 | 0 replies | |
| 15/15 | KVM: x86: implement PVCLOCK_TSC_STABLE_BIT pvclock flagarch/ | +110 | 0 replies |
Reviews trailers per patch
No Reviewed-by, Acked-by or Tested-by trailers for v1 yet.
Cover letter [patch 00/15] pvclock vsyscall support + KVM hypervisor support
This patchset, based on earlier work by Jeremy Fitzhardinge, implements paravirtual clock vsyscall support.
It should be possible to implement Xen support relatively easily.
It reduces clock_gettime from 500 cycles to 200 cycles on my testbox (including an mfence, that measurement).
NOTE: exporting pvclock tsc stable bit if the guest TSCs are not synchronized is incorrect, next version will have that fixed.
Please review.